==> patch-2.2.26.zip: app/language/en/pms.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'Policy Management',
	'backupPolicy' => 'Backup Policy',
	'schedule' => 'Backup Schedule',
	'schedules' => 'Backup Schedules',
	'filters' => 'Filters',
	'userPolicy' => 'User Policy Mapping',
	'multipleUserPolicy' => 'Policy mapping for multiple users',
	'networkThrottling' => 'Network Throttling',
	'create' => 'Create',
	'edit' => 'Edit',
	'list' => 'List',
	'polices' => 'Policies',
	'bPolices' => 'Backup Policies',
	'sPolices' => 'Server Backup Policies',
	'policy' => 'Policy',
	'bPolicy' => 'Backup Policy',
	'sPolicy' => 'Server Backup Policy',
	'change_user_policy' => 'Change User Policy',
	'policy_mapping' => 'Backup Policy Mapping',
	'paracloudblukrypt' => 'Paraclouds and Blukrypt Settings',
	'bluvault' => 'Paracloud',
	'blukrypt' => 'Blukrypt',
	'assign_policy_for_users_in_bulk' => 'Assign Policy for Users in bulk',
	'assign_policy' => 'Assign Policy',
	'cloudCredentials' => 'Cloud Credentials',

	// Common For all Methods
	'profileDisplay' => 'Account Details',
	'myDevices' => 'My Devices',
	'scheduleSaved' => 'Schedule updated successfully.',
	'filterSaved' 	=> 'Filter updated successfully.',
	'policySaved' 	=> 'Policy updated successfully.',
	'bluVaultNotInstalled' 	=> 'Please check if the Paracloud software has been installed on the specified machine.',
	'bluKryptNotInstalled' 	=> 'Please check if the BluKrypt software has been installed on the specified machine.',
	'421'       	=> 'Authentication token has <b>expired</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'cannotBlock'   => 'You cannot block <b>yourself</b>.  Please contact your Administrator for assistance.',
	'cannotDelete'  => 'You cannot delete <b>yourself</b>.   Please contact your Administrator for assistance.',
	'userBlocked'   => 'The selected user has been blocked successfully.',
	'userDeleted'   => 'The selected user has been deleted successfully.',
	'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
	'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
	'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
    'savedCloudCredentials'    	=> 'Cloud Credentials saved successfully',
    'savedAdCredentials'    	=> 'Active Directory Credentials saved successfully',
    'removeAdCredentials'    	=> 'Active Directory Credentials removed',
	'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.'
);

==> patch-2.3.5.0.zip: app/language/en/pms.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'Policy Management',
	'backupPolicy' => 'Backup Policy',
	'schedule' => 'Backup Schedule',
	'schedules' => 'Backup Schedules',
	'filters' => 'Filters',
	'userPolicy' => 'User Policy Mapping',
	'multipleUserPolicy' => 'Policy mapping for multiple users',
	'networkThrottling' => 'Network Throttling',
	'create' => 'Create',
	'edit' => 'Edit',
	'list' => 'List',
	'polices' => 'Policies',
	'bPolices' => 'Backup Policies',
	'sPolices' => 'Server Backup Policies',
	'policy' => 'Policy',
	'bPolicy' => 'Backup Policy',
	'sPolicy' => 'Server Backup Policy',
	'change_user_policy' => 'Change User Policy',
	'policy_mapping' => 'Backup Policy Mapping',
	'paracloudblukrypt' => 'Paraclouds and Blukrypt Settings',
	'bluvault' => 'Paracloud',
	'blukrypt' => 'Blukrypt',
	'assign_policy_for_users_in_bulk' => 'Assign Policy for Users in bulk',
	'assign_policy' => 'Assign Policy',
	'cloudCredentials' => 'Cloud Credentials',

	// Common For all Methods
	'profileDisplay' => 'Account Details',
	'myDevices' => 'My Devices',
	'scheduleSaved' => 'Schedule updated successfully.',
	'filterSaved' 	=> 'Filter updated successfully.',
	'policySaved' 	=> 'Policy updated successfully.',
	'bluVaultNotInstalled' 	=> 'Please check if the Paracloud software has been installed on the specified machine.',
	'bluKryptNotInstalled' 	=> 'Please check if the BluKrypt software has been installed on the specified machine.',
	'421'       	=> 'Authentication token has <b>expired</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'406'		=> 'Unable to delete the Blukrypt since it is already mapped to one or more policies. Detach it from all policies and try again.',
	'403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'cannotBlock'   => 'You cannot block <b>yourself</b>.  Please contact your Administrator for assistance.',
	'cannotDelete'  => 'You cannot delete <b>yourself</b>.   Please contact your Administrator for assistance.',
	'userBlocked'   => 'The selected user has been blocked successfully.',
	'userDeleted'   => 'The selected user has been deleted successfully.',
	'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
	'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
	'added_exclusion_folder'	=> 'Folder <b>added</b>  for exclusion.',
    	'savedCloudCredentials'    	=> 'Cloud Credentials saved successfully',
    	'savedAdCredentials'    	=> 'Active Directory Credentials saved successfully',
    	'removeAdCredentials'    	=> 'Active Directory Credentials deleted',
	'removeProxySettings'    	=> 'Proxy Settings deleted',
	'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.',
	'clonePolicy' => 'Clone Policy',
);
